@@ -15,17 +15,33 @@
 #include <limits.h>
 #include <math.h>
 #include <string.h>
-#include "api.h"
+
+#include "analyze-linkage.h"
+#include "corpus/corpus.h"
+#include "count.h"
 #include "disjuncts.h"
 #include "disjunct-utils.h"
 #include "error.h"
+#include "externs.h"
+#include "extract-links.h"
+#include "fast-match.h"
+#include "post-process.h"
 #include "preparation.h"
+#include "print.h"
+#include "prune.h"
 #include "regex-morph.h"
 #include "resources.h"
 #include "sat-solver/sat-encoder.h"
-#include "corpus/corpus.h"
 #include "spellcheck.h"
+#include "string-set.h"
+#include "structures.h"
+#include "tokenize.h"
 #include "utilities.h"
+#include "word-utils.h"
+
+#ifdef USE_FAT_LINKAGES
+#include "and.h"
+#endif /* USE_FAT_LINKAGES */
 
 /***************************************************************
 *
@@ -509,7 +525,7 @@ static void linkage_info_delete(Linkage_info *link_info, int sz)
 		lg_sense_delete(lifo);
 #endif
 	}
-	xfree(link_info, sz);
+	xfree(link_info, sz * sizeof(Linkage_info));
 }
 
 #ifdef USE_FAT_LINKAGES
@@ -1354,7 +1370,7 @@ void linkage_delete(Linkage linkage)
 		for (j = 0; j < s->num_links; ++j) {
 			exfree_link(s->link[j]);
 		}
-		exfree(s->link, sizeof(Link) * s->num_links);
+		exfree(s->link, sizeof(Link*) * s->num_links);
 		if (s->pp_info != NULL) {
 			for (j = 0; j < s->num_links; ++j) {
 				exfree_pp_info(&s->pp_info[j]);
