@@ -10,4 +10,7 @@
 /*                                                                       */
 /*************************************************************************/
 
+#include "api-types.h"
+#include "link-includes.h"
+
 void lg_compute_disjunct_strings(Sentence, Linkage_info *);
