@@ -18,9 +18,9 @@
 #include <limits.h>
 
 #include "build-disjuncts.h"
+#include "dict-api.h"
 #include "error.h"
 #include "externs.h"
-#include "read-dict.h"
 #include "regex-morph.h"
 #include "spellcheck.h"
 #include "string-set.h"
@@ -122,6 +122,19 @@ static Boolean is_quote(wchar_t wc)
 	return FALSE;
 }
 
+/**
+ * Return TRUE if the character is white-space
+ */
+static Boolean is_space(wchar_t wc)
+{
+	if (iswspace(wc)) return TRUE;
+
+	/* 0xc2 0xa0 is U+00A0, c2 a0, NO-BREAK SPACE */
+	/* For some reason, iswspace doesn't get this */
+	if (0xa0 == wc) return TRUE;
+	return FALSE;
+}
+
 /**
  * Returns true if the word can be interpreted as a number.
  * The ":" is included here so we allow "10:30" to be a number.
@@ -664,14 +677,12 @@ static void separate_word(Sentence sent, Parse_Options opts,
 		return;
 	}
 
-	/* Ugly hack: "let's" is in the english dict, but "Let's" is not. Thus,
-	 * sentences beginning with upper-case let's fail, while lower-case
-	 * pass! Again, need to fix this, since let's can also split into two ...
-	 * XXX should also check to see if its after a colon...
+	/* Ugly hack: "let's" is in the english dict, but "Let's" is not.
+	 * Thus, without this fix, sentences beginning with upper-case Let's
+	 * fail, while lower-case pass! So we work around this, since let's
+	 * can also split into two ...
 	 */
-	if (((dict->left_wall_defined && sent->length == 1) ||
-	    (!dict->left_wall_defined && sent->length == 0)) &&
-	    is_utf8_upper(word))
+	if (is_capitalizable(sent, sent->length) && is_utf8_upper(word))
 	{
 		char temp_word[MAX_WORD+1];
 		downcase_utf8_str(temp_word, word, MAX_WORD);
@@ -962,7 +973,7 @@ Boolean separate_sentence(Sentence sent, Parse_Options opts)
 		 */
 		isq = is_quote (c);
 		if (isq) quote_found = TRUE;
-		while (iswspace(c) || isq)
+		while (is_space(c) || isq)
 		{
 			word_start += nb;
 			nb = mbrtowc(&c, word_start, MB_CUR_MAX, &mbs);
@@ -978,7 +989,7 @@ Boolean separate_sentence(Sentence sent, Parse_Options opts)
 		word_end = word_start;
 		nb = mbrtowc(&c, word_end, MB_CUR_MAX, &mbs);
 		if (0 > nb) goto failure;
-		while (!iswspace(c) && !is_quote(c) && (c != 0) && (0 < nb))
+		while (!is_space(c) && !is_quote(c) && (c != 0) && (0 < nb))
 		{
 			word_end += nb;
 			nb = mbrtowc(&c, word_end, MB_CUR_MAX, &mbs);
