@@ -29,7 +29,8 @@
 #include <pthread.h>
 #endif
 
-#include "api.h"
+#include "structures.h"
+#include "utilities.h"
 
 #ifdef ENABLE_BINRELOC
 #include "prefix.h"
@@ -361,8 +362,14 @@ typedef struct
 {
 	size_t max_space_used;
 	size_t space_in_use;
+	size_t num_xallocs;
+	size_t num_xfrees;
+	size_t max_outstanding_xallocs;
 	size_t max_external_space_used;
 	size_t external_space_in_use;
+	size_t num_exallocs;
+	size_t num_exfrees;
+	size_t max_outstanding_exallocs;
 } space_t;
 
 #ifdef USE_PTHREADS
@@ -404,8 +411,14 @@ static space_t * do_init_memusage(void)
 
 	s->max_space_used = 0;
 	s->space_in_use = 0;
+	s->num_xallocs = 0;
+	s->num_xfrees = 0;
+	s->max_outstanding_xallocs = 0;
 	s->max_external_space_used = 0;
 	s->external_space_in_use = 0;
+	s->num_exallocs = 0;
+	s->num_exfrees = 0;
+	s->max_outstanding_exallocs = 0;
 
 	return s;
 }
@@ -465,6 +478,10 @@ void * xalloc(size_t size)
 	space_t *s = getspace();
 	s->space_in_use += size;
 	if (s->max_space_used < s->space_in_use) s->max_space_used = s->space_in_use;
+	s->num_xallocs ++;
+	if (s->max_outstanding_xallocs < (s->num_xallocs - s->num_xfrees))
+		s->max_outstanding_xallocs = (s->num_xallocs - s->num_xfrees);
+
 #endif /* TRACK_SPACE_USAGE */
 	if ((p == NULL) && (size != 0))
 	{
@@ -475,11 +492,13 @@ void * xalloc(size_t size)
 	return p;
 }
 
+#ifdef USE_FAT_LINKAGES
 void * xrealloc(void *p, size_t oldsize, size_t newsize)
 {
 #ifdef TRACK_SPACE_USAGE
 	space_t *s = getspace();
 	s->space_in_use -= oldsize;
+	s->num_xfrees ++;
 #endif /* TRACK_SPACE_USAGE */
 	p = realloc(p, newsize);
 	if ((p == NULL) && (newsize != 0))
@@ -490,15 +509,20 @@ void * xrealloc(void *p, size_t oldsize, size_t newsize)
 	}
 #ifdef TRACK_SPACE_USAGE
 	s->space_in_use += newsize;
+	s->num_xallocs ++;
 	if (s->max_space_used < s->space_in_use) s->max_space_used = s->space_in_use;
 #endif /* TRACK_SPACE_USAGE */
 	return p;
 }
+#endif /* USE_FAT_LINKAGES */
 
 #ifdef TRACK_SPACE_USAGE
 void xfree(void * p, size_t size)
 {
-	getspace()->space_in_use -= size;
+	space_t *s = getspace();
+	s->space_in_use -= size;
+	s->num_xfrees ++;
+
 	free(p);
 }
 #endif /* TRACK_SPACE_USAGE */
@@ -511,6 +535,9 @@ void * exalloc(size_t size)
 	s->external_space_in_use += size;
 	if (s->max_external_space_used < s->external_space_in_use)
 		s->max_external_space_used = s->external_space_in_use;
+	s->num_exallocs ++;
+	if (s->max_outstanding_exallocs < (s->num_exallocs - s->num_exfrees))
+		s->max_outstanding_exallocs = (s->num_exallocs - s->num_exfrees);
 #endif /* TRACK_SPACE_USAGE */
 
 	if ((p == NULL) && (size != 0))
@@ -525,7 +552,9 @@ void * exalloc(size_t size)
 #ifdef TRACK_SPACE_USAGE
 void exfree(void * p, size_t size)
 {
-	getspace()->external_space_in_use -= size;
+	space_t *s = getspace();
+	s->external_space_in_use -= size;
+	s->num_exfrees ++;
 	free(p);
 }
 #endif /* TRACK_SPACE_USAGE */
